Learn R Programming

kkmeans (version 0.1.3)

jump_stat: Function to get jump statistic for varying values of k

Description

Obtains the jump statistic for a particular kernel for the specified number of clusters

Usage

jump_stat(data, kern = "g", param = 1, k_max, eta, iter_max = 1000L)

Value

Sum of squares and value of jump statistic for 1, ..., K chosen clusters

Arguments

data

Numeric data to cluster. This will be converted to a matrix using as.matrix.

kern

The kernel to use.

param

The parameter value to pass to the kernel

k_max

The maximum number of clusters to consider

eta

Power for the jump statistic

iter_max

Maximum number of iterations to use in kkmeans call