Learn R Programming

kkmeans (version 0.1.3)

matr: Estimate the bandwidth parameter for a gaussian kernel using MATr

Description

given data and number of clusters K, choose a bandwidth from a grid according to the MATR algorithm

Usage

matr(dat, k, grid, tol = 0.01)

Value

A list with two elements. The first, l, contains the trace value for each of the values in grid. The second, best, contains the best value.

Arguments

dat

data vector

k

number of clusters

grid

parameter grid to search on

tol

tolerence for choosing the "best" sigma values. Reducing the tolerance will give larger values of the bandwidth parameter