Obtains the jump statistic for a particular kernel for the specified number of clusters
jump_stat(data, kern = "g", param = 1, k_max, eta, iter_max = 1000L)Sum of squares and value of jump statistic for 1, ..., K chosen clusters
Numeric data to cluster. This will be converted to a matrix using as.matrix.
The kernel to use.
The parameter value to pass to the kernel
The maximum number of clusters to consider
Power for the jump statistic
Maximum number of iterations to use in kkmeans call